MCD triple_N11
Affecter ( #projet, #employé u1, #site u1 )

- Le champ projet fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Projet.
- Le champ employé fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité Employé. Il obéit en outre à la contrainte d'unicité 1.
- Le champ site est une clé étrangère. Il a migré directement à partir de l'entité Site en perdant son caractère identifiant. Il obéit en outre à la contrainte d'unicité 1.

Employé ( employé, nom employé )

- Le champ employé constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Employé.
- Le champ nom employé était déjà un simple attribut de l'entité Employé.

Projet ( projet, libellé )

- Le champ projet constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Projet.
- Le champ libellé était déjà un simple attribut de l'entité Projet.

Site ( site, position )

- Le champ site constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Site.
- Le champ position était déjà un simple attribut de l'entité Site.